@@ -213,7 +213,7 @@ class TestResources(unittest.TestCase):
         resource = resources.Resource(
             {
                 resources.SERVICE_NAME: "test",
-                "non-primitive-data-type": dict(),
+                "non-primitive-data-type": {},
                 "invalid-byte-type-attribute": b"\xd8\xe1\xb7\xeb\xa8\xe5 \xd2\xb7\xe1",
                 "": "empty-key-value",
                 None: "null-key-value",
